==> zio-aws-macie2_2.12-5.17.130.3-sources.jar: zio/aws/macie2/model/DeclineInvitationsRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeclineInvitationsRequest(accountIds: Iterable[__string]) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DeclineInvitationsRequest = {
    import DeclineInvitationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DeclineInvitationsRequest
      .builder()
      .accountIds(accountIds.map { item =>
        __string.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.DeclineInvitationsRequest.ReadOnly =
    zio.aws.macie2.model.DeclineInvitationsRequest.wrap(buildAwsValue())
}
object DeclineInvitationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DeclineInvitationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.DeclineInvitationsRequest =
      zio.aws.macie2.model.DeclineInvitationsRequest(accountIds)
    def accountIds: List[__string]
    def getAccountIds: ZIO[Any, Nothing, List[__string]] =
      ZIO.succeed(accountIds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DeclineInvitationsRequest
  ) extends zio.aws.macie2.model.DeclineInvitationsRequest.ReadOnly {
    override val accountIds: List[__string] = impl
      .accountIds()
      .asScala
      .map { item =>
        zio.aws.macie2.model.primitives.__string(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DeclineInvitationsRequest
  ): zio.aws.macie2.model.DeclineInvitationsRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.12-5.17.169.1-sources.jar: zio/aws/macie2/model/DeclineInvitationsRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeclineInvitationsRequest(accountIds: Iterable[__string]) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DeclineInvitationsRequest = {
    import DeclineInvitationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DeclineInvitationsRequest
      .builder()
      .accountIds(accountIds.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.DeclineInvitationsRequest.ReadOnly =
    zio.aws.macie2.model.DeclineInvitationsRequest.wrap(buildAwsValue())
}
object DeclineInvitationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DeclineInvitationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.DeclineInvitationsRequest =
      zio.aws.macie2.model.DeclineInvitationsRequest(accountIds)
    def accountIds: List[__string]
    def getAccountIds: ZIO[Any, Nothing, List[__string]] =
      ZIO.succeed(accountIds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DeclineInvitationsRequest
  ) extends zio.aws.macie2.model.DeclineInvitationsRequest.ReadOnly {
    override val accountIds: List[__string] = impl
      .accountIds()
      .asScala
      .map { item =>
        item: __string
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DeclineInvitationsRequest
  ): zio.aws.macie2.model.DeclineInvitationsRequest.ReadOnly = new Wrapper(impl)
}
